{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "arvados/l7g"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "coresMax": 1
                }
            ],
            "hints": [
                {
                    "keep_cache": 4096,
                    "class": "http://arvados.org/cwl#RuntimeConstraints"
                }
            ],
            "baseCommand": "bash",
            "inputs": [
                {
                    "type": "File",
                    "label": "Master script to control cleaning",
                    "default": {
                        "class": "File",
                        "location": "https://raw.githubusercontent.com/curoverse/l7g/e4076d3ef7deda1bcc57bfe5e3d1dc7bf58238ff/cwl-version/clean/src/cleanCWL.sh"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#cleangvcf.cwl/bashscript"
                },
                {
                    "type": "string",
                    "label": "Tool to clean gVCFs",
                    "default": "/usr/local/bin/cleanvcf",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#cleangvcf.cwl/cleanvcf"
                },
                {
                    "type": "Directory",
                    "label": "Directory with gVCF files",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#cleangvcf.cwl/gvcfDir"
                },
                {
                    "type": "string",
                    "label": "Prefix of gVCF files",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#cleangvcf.cwl/gvcfPrefix"
                }
            ],
            "id": "#cleangvcf.cwl",
            "outputs": [
                {
                    "type": "Directory",
                    "label": "Directory of clean gVCFs",
                    "outputBinding": {
                        "glob": "cleaned/*"
                    },
                    "id": "#cleangvcf.cwl/out1"
                }
            ]
        },
        {
            "class": "ExpressionTool",
            "hints": [
                {
                    "loadListing": "shallow_listing",
                    "class": "http://commonwl.org/cwltool#LoadListingRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "loadContents": true
                    },
                    "id": "#getdirs_testset.cwl/datafilenames"
                },
                {
                    "type": "Directory",
                    "id": "#getdirs_testset.cwl/refdirectory"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "id": "#getdirs_testset.cwl/out1"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#getdirs_testset.cwl/out2"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "expression": "${\n  var samples = [];\n  var samplenames = [];\n  var wantednames = inputs.datafilenames.contents.split('\\n');\n  var nlines = wantednames.length;\n  for (var i = 0; i < inputs.refdirectory.listing.length; i++) {\n    var name = inputs.refdirectory.listing[i];\n    var type = name.class;\n    var basename = name.basename;\n       for (var j = 0; j < nlines; j++) {\n        var wantednamej = wantednames[j];\n          var result = wantednamej.indexOf(basename) > -1;\n            if (result) {\n            samples.push(name);\n            samplenames.push(basename);\n    }\n   }\n  }\n  return {\"out1\": samples,\"out2\": samplenames};\n}\n",
            "id": "#getdirs_testset.cwl"
        },
        {
            "class": "Workflow",
            "label": "Resolve duplicate/overlapping calls in the gVCFs in a named list",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "arvados/l7g"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 2,
                    "coresMax": 2
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "hints": [
                {
                    "keep_cache": 4096,
                    "class": "http://arvados.org/cwl#RuntimeConstraints"
                },
                {
                    "loadListing": "shallow_listing",
                    "class": "http://commonwl.org/cwltool#LoadListingRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/datafilenames"
                },
                {
                    "type": "Directory",
                    "id": "#main/refdirectory"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "Directory"
                    },
                    "outputSource": "#main/step2/out1",
                    "id": "#main/out1"
                }
            ],
            "steps": [
                {
                    "run": "#getdirs_testset.cwl",
                    "in": [
                        {
                            "source": "#main/datafilenames",
                            "id": "#main/step1/datafilenames"
                        },
                        {
                            "source": "#main/refdirectory",
                            "id": "#main/step1/refdirectory"
                        }
                    ],
                    "out": [
                        "#main/step1/out1",
                        "#main/step1/out2"
                    ],
                    "id": "#main/step1"
                },
                {
                    "scatter": [
                        "#main/step2/gvcfDir",
                        "#main/step2/gvcfPrefix"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/step1/out1",
                            "id": "#main/step2/gvcfDir"
                        },
                        {
                            "source": "#main/step1/out2",
                            "id": "#main/step2/gvcfPrefix"
                        }
                    ],
                    "run": "#cleangvcf.cwl",
                    "out": [
                        "#main/step2/out1"
                    ],
                    "id": "#main/step2"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0",
    "$namespaces": {
        "arv": "http://arvados.org/cwl#",
        "cwltool": "http://commonwl.org/cwltool#"
    }
}
